@@ -1,7 +1,6 @@
 package command
 
 import (
-	"io/ioutil"
 	"os"
 	"path/filepath"
 	"testing"
@@ -10,14 +9,14 @@ import (
 // setupMigrationFile is a test helper for setting up a temporary migration file.
 // It returns a path of migration file.
 func setupMigrationFile(t *testing.T, source string) string {
-	migrationDir, err := ioutil.TempDir("", "migrationDir")
+	migrationDir, err := os.MkdirTemp("", "migrationDir")
 	if err != nil {
 		t.Fatalf("failed to craete migration dir: %s", err)
 	}
 	t.Cleanup(func() { os.RemoveAll(migrationDir) })
 
 	path := filepath.Join(migrationDir, "test.hcl")
-	err = ioutil.WriteFile(path, []byte(source), 0600)
+	err = os.WriteFile(path, []byte(source), 0600)
 	if err != nil {
 		t.Fatalf("failed to write migration file: %s", err)
 	}
@@ -29,7 +28,7 @@ func setupMigrationFile(t *testing.T, source string) string {
 // A given migrations is a map of filename to source of migration file.
 // It returns a path of migration dir.
 func setupMigrationDir(t *testing.T, migrations map[string]string) string {
-	migrationDir, err := ioutil.TempDir("", "migrationDir")
+	migrationDir, err := os.MkdirTemp("", "migrationDir")
 	if err != nil {
 		t.Fatalf("failed to craete migration dir: %s", err)
 	}
@@ -37,7 +36,7 @@ func setupMigrationDir(t *testing.T, migrations map[string]string) string {
 
 	for filename, source := range migrations {
 		path := filepath.Join(migrationDir, filename)
-		err = ioutil.WriteFile(path, []byte(source), 0600)
+		err = os.WriteFile(path, []byte(source), 0600)
 		if err != nil {
 			t.Fatalf("failed to write migration file: %s", err)
 		}
